@@ -8,7 +8,7 @@ class alertRuleController:
         self._gracie = gracie
 
     def add(self, name, projectId, **kwargs):
-        """Create new alert rule for project.
+        """
 
         Args:
             description: (string): description
@@ -32,7 +32,7 @@ class alertRuleController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def delete(self, id):
-        """Remove existing alert rule.
+        """
 
         Args:
             id: (string): id
@@ -53,7 +53,7 @@ class alertRuleController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def edit(self, id, **kwargs):
-        """Edit existing alert rule.
+        """
 
         Args:
             description: (string): description
@@ -77,7 +77,7 @@ class alertRuleController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def list(self, projectId, **kwargs):
-        """Return list of alert rules for project.
+        """
 
         Args:
             orderAsc: (boolean): orderAsc
@@ -100,7 +100,7 @@ class alertRuleController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, id):
-        """Return the alert rule by ID.
+        """
 
         Args:
             id: (string): id
