@@ -8,7 +8,7 @@ class alerterController:
         self._gracie = gracie
 
     def add(self, alertRuleId, email, name, **kwargs):
-        """Create new Email alerter for alert rule.
+        """
 
         Args:
             alertRuleId: (string): alertRuleId
@@ -33,7 +33,7 @@ class alerterController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def delete(self, id):
-        """Remove existing alerter.
+        """
 
         Args:
             id: (string): id
@@ -54,7 +54,7 @@ class alerterController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def edit(self, id, **kwargs):
-        """Edit Email alerter for alert rule.
+        """
 
         Args:
             bcc: (array): bcc
@@ -79,7 +79,7 @@ class alerterController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def list(self, alertRuleId, **kwargs):
-        """Return list of alerters for alertRule.
+        """
 
         Args:
             alertRuleId: (string): alertRuleId
@@ -102,7 +102,7 @@ class alerterController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, id):
-        """Return an alerter by ID.
+        """
 
         Args:
             id: (string): id
