@@ -8,7 +8,7 @@ class engineAppInfoController:
         self._gracie = gracie
 
     def retrieve(self):
-        """Return EngineApp info."""
+        """"""
 
         all_api_parameters = {}
         parameters_names_map = {}
@@ -19,7 +19,7 @@ class engineAppInfoController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def searchParameters(self):
-        """Return info."""
+        """"""
 
         all_api_parameters = {}
         parameters_names_map = {}
@@ -30,7 +30,7 @@ class engineAppInfoController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def system(self):
-        """Return info."""
+        """"""
 
         all_api_parameters = {}
         parameters_names_map = {}
