@@ -8,7 +8,7 @@ class entitiesController:
         self._gracie = gracie
 
     def getTopicEntities(self, languageId, name, **kwargs):
-        """Return JSON array of the objects which represent the entities with the requested name.
+        """
 
         Args:
             languageId: (string): languageId
@@ -34,7 +34,7 @@ class entitiesController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def topicRetrieve(self, entityId):
-        """Return the entity with specified ID.
+        """
 
         Args:
             entityId: (string): entityId
