@@ -8,7 +8,7 @@ class filtersController:
         self._gracie = gracie
 
     def getFiltersTree(self, alertRuleId):
-        """Get filters tree.
+        """
 
         Args:
             alertRuleId: (string): alertRuleId
@@ -29,7 +29,7 @@ class filtersController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def removeFiltersTree(self, alertRuleId):
-        """Remove filters tree.
+        """
 
         Args:
             alertRuleId: (string): alertRuleId
@@ -50,7 +50,7 @@ class filtersController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def setFiltersTree(self, alertRuleId, filters):
-        """Set filters tree.
+        """
 
         Args:
             alertRuleId: (string): alertRuleId
