@@ -8,7 +8,7 @@ class performanceController:
         self._gracie = gracie
 
     def enable(self, enabled):
-        """Switch enableStatistics flag ON.
+        """
 
         Args:
             enabled: (boolean): enabled
@@ -29,7 +29,7 @@ class performanceController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self):
-        """Return the statistics instance."""
+        """"""
 
         all_api_parameters = {}
         parameters_names_map = {}
