@@ -8,7 +8,7 @@ class pipelineController:
         self._gracie = gracie
 
     def add(self, name, pipeline, **kwargs):
-        """Create new text processing pipeline for authenticated user.
+        """
 
         Args:
             description: (string): description
@@ -31,7 +31,7 @@ class pipelineController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def defaultRules(self):
-        """Returns default text processing pipeline."""
+        """"""
 
         all_api_parameters = {}
         parameters_names_map = {}
@@ -42,7 +42,7 @@ class pipelineController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def delete(self, id):
-        """Remove existing text processing pipeline for authenticated user.
+        """
 
         Args:
             id: (string): id
@@ -63,7 +63,7 @@ class pipelineController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def edit(self, id, name, pipeline, **kwargs):
-        """Edit existing text processing pipeline by ID.
+        """
 
         Args:
             description: (string): description
@@ -87,7 +87,7 @@ class pipelineController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def list(self, **kwargs):
-        """Return the list of text processing pipeline for authenticated user.
+        """
 
         Args:
             orderAsc: (boolean): orderAsc
@@ -109,7 +109,7 @@ class pipelineController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, id):
-        """Return the text processing pipeline with specified ID.
+        """
 
         Args:
             id: (string): id
@@ -130,7 +130,7 @@ class pipelineController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def ruleOrigin(self, ruleId, **kwargs):
-        """Return the rule.
+        """
 
         Args:
             languageId: (string): languageId
@@ -152,7 +152,7 @@ class pipelineController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def rulesOrigin(self, **kwargs):
-        """Return the list of all rules.
+        """
 
         Args:
             languageId: (string): languageId
