@@ -8,7 +8,7 @@ class skillsetsController:
         self._gracie = gracie
 
     def list(self):
-        """Return list of skillsets."""
+        """"""
 
         all_api_parameters = {}
         parameters_names_map = {}
@@ -19,7 +19,7 @@ class skillsetsController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, skillsetId):
-        """Retrieve existing skillset.
+        """
 
         Args:
             skillsetId: (string): skillsetId
