@@ -8,7 +8,7 @@ class topicsController:
         self._gracie = gracie
 
     def list(self):
-        """Return the list of topics."""
+        """"""
 
         all_api_parameters = {}
         parameters_names_map = {}
@@ -19,7 +19,7 @@ class topicsController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, id):
-        """Return the topic with specified ID.
+        """
 
         Args:
             id: (string): id
