@@ -8,7 +8,7 @@ class typesController:
         self._gracie = gracie
 
     def list(self, **kwargs):
-        """Return the list of types.
+        """
 
         Args:
             dictionaryId: (string): dictionaryId
@@ -29,7 +29,7 @@ class typesController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, id):
-        """Return the type with specified ID.
+        """
 
         Args:
             id: (string): id
