@@ -8,7 +8,7 @@ class usersController:
         self._gracie = gracie
 
     def add(self, login, password, **kwargs):
-        """Create new user.
+        """
 
         Args:
             description: (string): description
@@ -32,7 +32,7 @@ class usersController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def edit(self, id, **kwargs):
-        """Edit existing user.
+        """
 
         Args:
             description: (string): description
@@ -57,7 +57,7 @@ class usersController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def editUserAttributes(self, **kwargs):
-        """Edit user attributes.
+        """
 
         Args:
             dashboardsRefreshEvery: (string): dashboardsRefreshEvery
@@ -79,7 +79,7 @@ class usersController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def list(self):
-        """Return the list of users"""
+        """"""
 
         all_api_parameters = {}
         parameters_names_map = {}
@@ -90,7 +90,7 @@ class usersController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def remove(self, id):
-        """Remove existing user.
+        """
 
         Args:
             id: (string): id
@@ -111,7 +111,7 @@ class usersController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieveUserAttributes(self):
-        """Return attributes of user's account."""
+        """"""
 
         all_api_parameters = {}
         parameters_names_map = {}
@@ -122,7 +122,7 @@ class usersController:
         return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def whoAmI(self):
-        """Return the user information."""
+        """"""
 
         all_api_parameters = {}
         parameters_names_map = {}
